/*
 * ct.c         "ct" utility frontend
 *
 *              This program is free software; you can redistribute it and/or
 *              modify it under the terms of the GNU General Public License
 *              as published by the Free Software Foundation; either version
 *              2 of the License, or (at your option) any later version.
 *
 * Authors:     Patrick McHardy, <kaber@trash.net>
 */

#include <stdio.h>
#include <stdlib.h>
#include <errno.h>

#include "ct.h"
#include "utils.h"

void incomplete_command(void)
{
	fprintf(stderr, "Command line is not complete. Try option \"help\".\n");
	exit(1);
}

int unknown_arg(char *arg)
{
	fprintf(stderr, "Argument \"%s\" is unknown, try help.\n", arg);
	return -1;
}

static void usage(char *progname)
{
	fprintf(stderr, "Usage: %s [ add | change | del | list | monitor ] [ help ]\n", progname);
	exit(1);
}

int main(int argc, char **argv)
{
	char *progname;

	progname = *argv;
	argv++, argc--;

	if (argc < 1) {
		usage(progname);
		exit(1);
	}

	if (matches(*argv, "monitor"))
		return ctmonitor(argc - 1, argv + 1);
	else if (matches(*argv, "add"))
		return ctadd(argc - 1, argv + 1);
	else if (matches(*argv, "sync"))
		return ctsyncd(argc - 1, argv + 1);
/*
	else if (matches(*argv, "change"))
		return ctchange(argc - 1, argv + 1);
	else if (matches(*argv, "del"))
		return ctdel(argc - 1, argv + 1);
	else if (matches(*argv, "list"))
		return ctlist(argc - 1, argv + 1);
*/
	else if (matches(*argv, "help"))
		usage(progname);
	else {
		fprintf(stderr, "Argument \"%s\" is unknown, try \"ct help\".\n"
				, *argv);
		exit(1);
	}

	exit(0);
}
