/*
 * ctchange.c   "ct add/change/delete"
 *
 *              This program is free software; you can redistribute it and/or
 *              modify it under the terms of the GNU General Public License
 *              as published by the Free Software Foundation; either version
 *              2 of the License, or (at your option) any later version.
 *
 * Authors:     Patrick McHardy, <kaber@trash.net>
 */

#include <stdio.h>
#include <stdlib.h>
#include <errno.h>

#include "ct.h"
#include "utils.h"

static void usage(void)
{
	fprintf(stderr, "Usage: [ add | change | del | list | monitor | help ]\n");
}

static void explain(char *arg)
{
	fprintf(stderr, "Illegal \"%s\"\n", arg);
}

int ctadd(int argc, char **argv)
{
	struct ip_conntrack_tuple orig, reply;
	struct cta_proto cp;
	struct cta_help ch;
	struct cta_nat cn;
	unsigned long status, timeout, mark;
	int orig_f = 0, reply_f = 0, proto_f = 0, help_f = 0, nat_f = 0,
	    status_f = 0, timeout_f = 0, mark_f = 0;
	
	while (argc > 0) {
		int i = 1;
		if (matches(*argv, "orig")) {
			NEXT_ARG();
			if ((i = get_tuple(&orig, argc, argv)) < 0) {
				explain("orig");
				return -1;
			}
			orig_f = 1;
		} else if (matches(*argv, "reply")) {
			NEXT_ARG();
			if ((i = get_tuple(&reply, argc, argv)) < 0) {
				explain("reply");
				return -1;
			}
			reply_f = 1;
		} else if (matches(*argv, "status")) {
			NEXT_ARG();
			if (get_status(&status, *argv)) {
				explain("status");
				return -1;
			}
			status_f = 1;
		} else if (matches(*argv, "protoinfo")) {
			NEXT_ARG();
			if ((i = get_protoinfo(&cp, argc, argv)) < 0) {
				explain("protoinfo");
				return -1;
			}
			proto_f = 1;
		} else if (matches(*argv, "helpinfo")) {
			NEXT_ARG();
			if ((i = get_helpinfo(&ch, argc, argv)) < 0) {
				explain("helpinfo");
				return -1;
			}
			help_f = 1;
		} else if (matches(*argv, "natinfo")) {
			NEXT_ARG();
			if ((i = get_natinfo(&cn, argc, argv)) < 0) {
				explain("natinfo");
				return -1;
			}
			nat_f = 1;
		} else if (matches(*argv, "timeout")) {
			NEXT_ARG();
			if (get_ulong(&timeout, *argv, 0)) {
				explain("timeout");
				return -1;
			}
			timeout_f = 1;
		} else if (matches(*argv, "mark")) {
			NEXT_ARG();
			if (get_ulong(&mark, *argv, 0)) {
				explain("mark");
				return -1;
			}
			mark_f = 1;
		} else if (matches(*argv, "help")) {
			usage();
			return -1;
		} else
			return unknown_arg(*argv);
		argc -= i, argv += i;
	}

	if (!(orig_f & reply_f & proto_f & status_f & timeout_f)) {
		fprintf(stderr, "Required attributes missing\n");
		return -1;
	}
	
	return 0;
}
